import React, { useEffect, useState } from "react";
import EventCard from "../Components/EventCard";
import { getAllEvents } from "../api/events";
import Grid from "@mui/material/Grid";
import Typography from "@mui/material/Typography";
import Modal from "@mui/material/Modal";
import { getLocalStorage, } from "../Helpers/localStorage"

const Marketplace = () => {
  // List of events taken from DB
  const [allEvents, setAllEvents] = useState([]);

  //User object
  const [user, setUser] = useState(null);

  // Selected event to show modal for - If null show list instead!
  const [selectedEvent, setSelectedEvent] = useState(null);

  // Get all events for the list on marketplace
  useEffect(() => {
    async function getEvents() {
      let events = await getAllEvents();
      console.log(events.data)
      setAllEvents(events.data)
    }
    getEvents();
    setUser(getLocalStorage('user'))
  }, []);

  return (
    <Grid container spacing={2} sx={{ padding: "50px 80px" }}>
      <>
        <Grid item container xs={12}>
          <Typography variant={"h5"}>All Events</Typography>
        </Grid>
        <Grid item container xs={12} spacing={2}>
          {allEvents.map((val) => {
            return (
              <Grid item xs={4}>
                <EventCard
                  eventData={val}
                  type={"small"}
                  setSelectedEvent={setSelectedEvent}
                />
              </Grid>
            );
          })}
        </Grid>
      </>

      <Modal
        open={selectedEvent !== null}
        onClose={() => {
          setSelectedEvent(null);
        }}
        aria-labelledby="View Event"
        aria-describedby="Learn more about your favourite artist and their events from this modal."
      >
        <Grid container xs={12} sx={{height: '90vh', marginTop: '5vh', overflowY: 'scroll'}} alignItems={'center'}>
          <Grid
            item
            container
            xs={10}
            sx={{ backgroundColor: "white", margin: "auto", padding: "35px" }}
          >
            <EventCard eventData={selectedEvent} type={'large'} setSelectedEvent={setSelectedEvent} user={user} />
          </Grid>
        </Grid>
      </Modal>
    </Grid>
  );
};

export default Marketplace;
